@@ -58,7 +58,7 @@ void QMLScreen::setConfig(const KScreen::ConfigPtr &config)
 {
     qDeleteAll(m_outputMap);
     m_outputMap.clear();
-    m_bottommost = m_leftmost = m_rightmost = m_topmost = 0;
+    m_bottommost = m_leftmost = m_rightmost = m_topmost = nullptr;
     m_connectedOutputsCount = 0;
     m_enabledOutputsCount = 0;
 
@@ -186,7 +186,7 @@ QSize QMLScreen::maxScreenSize() const
 
 float QMLScreen::outputScale() const
 {
-    return m_outputScale;
+    return 1.0 / 8.0;
 }
 
 void QMLScreen::outputConnectedChanged()
@@ -286,10 +286,10 @@ void QMLScreen::viewSizeChanged()
 
 void QMLScreen::updateCornerOutputs()
 {
-    m_leftmost = 0;
-    m_topmost = 0;
-    m_rightmost = 0;
-    m_bottommost = 0;
+    m_leftmost = nullptr;
+    m_topmost = nullptr;
+    m_rightmost = nullptr;
+    m_bottommost = nullptr;
 
     Q_FOREACH (QMLOutput *output, m_outputMap) {
         if (!output->output()->isConnected() || !output->output()->isEnabled()) {
@@ -315,20 +315,37 @@ void QMLScreen::updateCornerOutputs()
     }
 }
 
-void QMLScreen::setOutputScale(float scale)
-{
-    if (qFuzzyCompare(scale, m_outputScale))
-        return;
-    m_outputScale = scale;
-    emit outputScaleChanged();
-}
-
 void QMLScreen::updateOutputsPlacement()
 {
-    if (width() <= 0)
-        return;
+    int disabledOffsetX = width();
+    QSizeF activeScreenSize;
 
-    QSizeF initialActiveScreenSize;
+    Q_FOREACH (QQuickItem *item, childItems()) {
+        QMLOutput *qmlOutput = qobject_cast<QMLOutput*>(item);
+        if (!qmlOutput->output()->isConnected()) {
+            continue;
+        }
+
+        if (!qmlOutput->output()->isEnabled()) {
+            qmlOutput->blockSignals(true);
+            disabledOffsetX -= qmlOutput->width();
+            qmlOutput->setPosition(QPoint(disabledOffsetX, 0));
+            qmlOutput->blockSignals(false);
+            continue;
+        }
+
+        if (qmlOutput->outputX() + qmlOutput->currentOutputWidth() > activeScreenSize.width()) {
+            activeScreenSize.setWidth(qmlOutput->outputX() + qmlOutput->currentOutputWidth());
+        }
+        if (qmlOutput->outputY() + qmlOutput->currentOutputHeight() > activeScreenSize.height()) {
+            activeScreenSize.setHeight(qmlOutput->outputY() + qmlOutput->currentOutputHeight());
+        }
+    }
+
+    activeScreenSize *= outputScale();
+
+    const QPointF offset((width() - activeScreenSize.width()) / 2.0,
+                         (height() - activeScreenSize.height()) / 2.0);
 
     Q_FOREACH (QQuickItem *item, childItems()) {
         QMLOutput *qmlOutput = qobject_cast<QMLOutput*>(item);
@@ -336,57 +353,11 @@ void QMLScreen::updateOutputsPlacement()
             continue;
         }
 
-        if (qmlOutput->outputX() + qmlOutput->currentOutputWidth() > initialActiveScreenSize.width()) {
-            initialActiveScreenSize.setWidth(qmlOutput->outputX() + qmlOutput->currentOutputWidth());
-        }
-        if (qmlOutput->outputY() + qmlOutput->currentOutputHeight() > initialActiveScreenSize.height()) {
-            initialActiveScreenSize.setHeight(qmlOutput->outputY() + qmlOutput->currentOutputHeight());
-        }
+        qmlOutput->blockSignals(true);
+        qmlOutput->setPosition(QPointF(offset.x() + (qmlOutput->outputX() * outputScale()),
+                          offset.y() + (qmlOutput->outputY() * outputScale())));
+        qmlOutput->blockSignals(false);
     }
-
-    auto initialScale = outputScale();
-    auto scale = initialScale;
-    qreal lastX = -1.0;
-    do {
-        auto activeScreenSize = initialActiveScreenSize * scale;
-
-        const QPointF offset((width() - activeScreenSize.width()) / 2.0,
-                             (height() - activeScreenSize.height()) / 2.0);
-
-        lastX = -1.0;
-        qreal lastY = -1.0;
-        Q_FOREACH (QQuickItem *item, childItems()) {
-            QMLOutput *qmlOutput = qobject_cast<QMLOutput*>(item);
-            if (!qmlOutput->output()->isConnected() || !qmlOutput->output()->isEnabled()) {
-                continue;
-            }
-
-            qmlOutput->blockSignals(true);
-            qmlOutput->setPosition(QPointF(offset.x() + (qmlOutput->outputX() * scale),
-                              offset.y() + (qmlOutput->outputY() * scale)));
-            lastX = qMax(lastX, qmlOutput->position().x() + qmlOutput->width() / initialScale * scale);
-            lastY = qMax(lastY, qmlOutput->position().y());
-            qmlOutput->blockSignals(false);
-        }
-
-        Q_FOREACH (QQuickItem *item, childItems()) {
-            QMLOutput *qmlOutput = qobject_cast<QMLOutput*>(item);
-            if (qmlOutput->output()->isConnected() && !qmlOutput->output()->isEnabled()) {
-                qmlOutput->blockSignals(true);
-                qmlOutput->setPosition(QPointF(lastX, lastY));
-                lastX += qmlOutput->width() / initialScale * scale;
-                qmlOutput->blockSignals(false);
-            }
-        }
-        // calculate the scale dynamically, so all screens fit to the dialog
-        if (lastX > width()) {
-            scale *= 0.8;
-        }
-    } while (lastX > width());
-    // Use a timer to avoid binding loop on width()
-    QTimer::singleShot(0, this, [scale, this] {
-        setOutputScale(scale);
-    });
 }
 
 void QMLScreen::setEngine(QQmlEngine* engine)
